@@ -1,6 +1,6 @@
 # Display four equally likely intervals as coloured bars
 
-makeQuartilePlot <- function(lower, Q1, m, Q3, upper, fontsize=12){
+makeQuartilePlot <- function(lower, Q1, m, Q3, upper, fontsize=12, xlab = "x"){
   ggplot()+
     annotate("rect", xmin = lower, 
              xmax = Q1, ymin=0.2, ymax = 0.8, fill = "#a6cee3")+
@@ -11,7 +11,7 @@ makeQuartilePlot <- function(lower, Q1, m, Q3, upper, fontsize=12){
     xlim(lower, upper)+
     theme(axis.ticks.y = element_blank(), axis.text.y = element_blank())+
     scale_y_continuous(breaks = NULL, limits = c(0, 1))+
-    labs(title = "Quartiles", y = expression(f[X](x)), x = "x") +
+    labs(title = "Quartiles", y = expression(f[X](x)), x = xlab) +
     theme(plot.title = element_text(hjust = 0.5),
           axis.title.y = element_text(colour = "white"),
           text = element_text(size = fontsize))
